package Example89;

BEGIN {
	$Example89::AUTHORITY = 'cpan:TOBYINK';
	$Example89::VERSION   = '1.234';
}

use authority::shared q<http://tobyinkster.co.uk/#i>;
use namespace::autoclean;
use Devel::Sub::Which qw(:universal);

1;
